*********************************************************************************************;
*       PROGRAM: Read_PSU_87.sas                                                            *;
*          NOTE: 1) This program reads in the following three 1987-88 nonfiscal CCD         *;
*                   school data files and creates an SAS system data file:                  *;
*                   a) PSU87AI.TXT - States A-I  (Alabama - Iowa)                           *;
*                   b) PSU87KN.TXT - States K-N  (Kansas - North Dakota)                    *;
*                   c) PSU87OW.TXT - States O-W  (Ohio - Wyoming)                           *;
*                   *  Other jurisdictions are included in the files.                       *;
*                2) Change the path in each of the input file macro variables to point to   *;
*                   the location of PSU87AI.TXT, PSU87KN.TX, and PSU87OW.TXT respectively.  *;
*                3) Change LIBNAME path to point to where the SAS system data files will    *;
*                   be saved.                                                               *;
*                4) This program does not save the three intermediate SAS system files on   *; 
*                   your hard drive.                                                        *;
*    WRITTEN BY: Pinkerton Computer Consultants, Inc., November 8, 2005                     *;
*    UPDATED BY: National Center for Education Statistics                                   *;
*  LAST UPDATED: March 1, 2006                                                              *;
*********************************************************************************************;

*** Change libname path for saving your SAS system data set ***;
libname out 'h:\ccd\data\nf\y8788\school\out\';

*** Change the file paths in the 3 macro variables below for the raw data files;
%let ai="h:\ccd\data\nf\y8788\school\psu87ai.txt";
%let kn="h:\ccd\data\nf\y8788\school\psu87kn.txt";
%let ow="h:\ccd\data\nf\y8788\school\psu87ow.txt";

**********************************************************;
***    Do not make any change below unless necessary   ***;
**********************************************************;
%macro sch (sch_in, sch_out);
  data &sch_out;
  infile &sch_in missover lrecl=274;
  missing m n;
  input (ncessch fips   leaid  schno stid87 leanm87 seasch87 schnam87 street87 city87 st87)
  		($12.    @1 $2. @1 $7. $5.   $14.   $30.    $20.     $30.     $25.     $18.   $2.)
  		(zip87 zip487 phone87 type87 status87 locale87 fte87 grspan87 gslo87   gshi87)
		($5.   $4.    $10.    $1.    $1.       $1.      5.1   $4.      @179 $2. $2.)
		(ug87 pk87 kg87 g0187 g0287 g0387 g0487 g0587 g0687 g0787 g0887 g0987 g1087 g1187 g1287)(4.)
		(member87 fle87 ind87 asian87 hisp87 black87 white87 year) (5. 5. 4. 4. 4. 4. 4. 2.);
  run;
%mend sch;

%sch(&ai, sch87_ai);
%sch(&kn, sch87_kn);
%sch(&ow, sch87_ow);

*** Combining the 3 SAS data sets and save the resultant file ***;
data out.psu87 (label='CCD.School.1987-88');
  set sch87_ai sch87_kn sch87_ow;
  label
	ncessch		='NCES Unique School ID'
	fips  		='FIPS State Numerical Code'
	leaid		='NCES Assigned Agency ID'
	schno		='NCES Assigned School ID'
	stid87  	='State Agency ID'
	leanm87		='Agneyc Name'
	seasch87	='State Assigned School ID'
	schnam87	='School Name'
	street87	='Mailing Address'
	city87 		='Mailing City Name'
	st87		='FIPS State Alpha Code'
	zip87		='Zip Code'
	zip487		='Zip Code Extention'
	phone87		='Telephone Number'
	type87  	='School Type'
	status87	='Operational Status'
	locale87	='Locale Code'
	fte87		='Classroom Teachers (FTE)'
	grspan87	='School Grade Span'
	gslo87		='Lowest Grade Offered'
	gshi87		='Highest Grade Offered'
	ug87		='Total Ungraded Students'
	pk87		='Total Prekindergarten Students'
	kg87		='Total Kindergarten Students'
	g0187		='Total 1st Grade Students'
	g0287		='Total 2nd Grade Students'
	g0387		='Total 3rd Grade Students'
	g0487		='Total 4th Grade Students'
	g0587		='Total 5th Grade Students'
	g0687		='Total 6th Grade Students'
	g0787		='Total 7th Grade Students'
	g0887		='Total 8th Grade Students'
	g0987		='Total 9th Grade Students'
	g1087		='Total 10th Grade Students'
	g1187		='Total 11th Grade Students'
	g1287		='Total 12th Grade Students'
	member87	='Total Students of All Grades'
	fle87		='Free-Lunch Eligible Students'
	ind87		='AM Indian/Alaskan Students'
	asian87		='Asian/Pacific Islander Students'
	hisp87 		='Hispanic Students'
	black87		='Black Non-Hispanic Students'
	white87		='White Non-Hispanic Students'
	year  		='School year (Fall)';
proc format;
  value $fipsf
	'01'  ='01-Alabama'			'02'  ='02-Alaska'			'03'  ='03-American Somoa'
	'04'  ='04-Arizona'			'05'  ='05-Arkansas'		'06'  ='06-California'
	'08'  ='08-Colorado'		'09'  ='09-Connecticut'		'10'  ='10-Delaware'
	'11'  ='11-District of Columbia'						'12'  ='12-Florida'
	'13'  ='13-Georgia'			'14'  ='14-Guam'			'15'  ='15-Hawaii'
	'16'  ='16-Idaho'			'17'  ='17-Illinois'		'18'  ='18-Indiana'
	'19'  ='19-Iowa'			'20'  ='20-Kansas'			'21'  ='21-Kentucky'
	'22'  ='22-Louisiana'		'23'  ='23-Maine'			'24'  ='24-Maryland'
	'25'  ='25-Massachusetts'	'26'  ='26-Michigan'		'27'  ='27-Minnesota'
	'28'  ='28-Mississippi'		'29'  ='29-Missouri'		'30'  ='30-Montana'
	'31'  ='31-Nebraska'		'32'  ='32-Nevada'			'33'  ='33-New Hampshire'
	'34'  ='34-New Jersey'		'35'  ='35-New Mexico'		'36'  ='36-New York'
	'37'  ='37-North Carolina'	'38'  ='38-North Dakota'	'39'  ='39-Ohio'
	'40'  ='40-Oklahoma'		'41'  ='41-Oregon'			'42'  ='42-Pennsylvania'
	'43'  ='43-Puerto Rico'		'44'  ='44-Rhode Island'	'45'  ='45-South Carolina'
	'46'  ='46-South Dakota'	'47'  ='47-Tennessee'		'48'  ='48-Texas'
	'49'  ='49-Utah'			'50'  ='50-Vermont'			'51'  ='51-Virginia'
	'52'  ='52-Virgin Islands'	'53'  ='53-Washington'		'54'  ='54-West Virginia'
	'55'  ='55-Wisconsin'		'56'  ='56-Wyoming'			'60'  ='60-Northern Marianas';
  value $typef
	'1'  ='1-Regular School'
	'2'  ='2-Special education School'
	'3'  ='3-Vocational School'
	'4'  ='4-Other/alternative School';
  value $statusf
	' '  ='Missing'
	'1'  ='1-Open - Continues Operational From PY Report'
	'2'  ='2-Closed - Since Last Report'
	'3'  ='3-New - Opened Since Last Report'
	'4'  ='4-Added - Open But Not Reported PY';
  value $localef
	' '  ='Missing'
	'1'  ='1-Large Central City'
	'2'  ='2-Mid-size Central City'
	'3'  ='3-Urban Fringe of Large City'
	'4'  ='4-Urban Fringe of Mid-size City'
	'5'  ='5-Large Town'
	'6'  ='6-Small Town'
	'7'  ='7-Rural';
  value $gslof
	'00 ' ='No Students Reported'
	'01'  ='1st Grade'
	'02'  ='2nd Grade'
	'03'  ='3rd Grade'
	'04'  ='4th Grade'
	'05'  ='5th Grade'
	'06'  ='6th Grade'
	'07'  ='7th Grade'
	'08'  ='8th Grade'
	'09'  ='9th Grade'
	'10'  ='10th Grade'
	'11'  ='11th Grade'
	'12'  ='12th Grade'
	'KG'  ='Kindergarten'
	'PK'  ='PreKindergarten'
	'UG'  ='Ungraded';
  value $gshif
	'00'  ='No Students Reported'
	'01'  ='1st Grade'
	'02'  ='2nd Grade'
	'03'  ='3rd Grade'
	'04'  ='4th Grade'
	'05'  ='5th Grade'
	'06'  ='6th Grade'
	'07'  ='7th Grade'
	'08'  ='8th Grade'
	'09'  ='9th Grade'
	'10'  ='10th Grade'
	'11'  ='11th Grade'
	'12'  ='12th Grade'
	'KG'  ='Kindergarten'
	'PK'  ='PreKindergarten'
	'UG'  ='Ungraded';
run;
